
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

/*
 * Copyright (C) 2023 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WPEEnumTypes_h
#define WPEEnumTypes_h

#if !defined(__WPE_PLATFORM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <wpe/wpe-platform.h> can be included directly."
#endif

#include <glib-object.h>
#include <wpe/WPEDefines.h>

G_BEGIN_DECLS
/* Enumerations from WPEBuffer.h. */
#define WPE_TYPE_BUFFER_ERROR wpe_buffer_error_get_type()

WPE_API GType wpe_buffer_error_get_type(void);
/* Enumerations from WPEBufferFormats.h. */
#define WPE_TYPE_BUFFER_FORMAT_USAGE wpe_buffer_format_usage_get_type()

WPE_API GType wpe_buffer_format_usage_get_type(void);
/* Enumerations from WPEBufferSHM.h. */
#define WPE_TYPE_PIXEL_FORMAT wpe_pixel_format_get_type()

WPE_API GType wpe_pixel_format_get_type(void);
/* Enumerations from WPEDisplay.h. */
#define WPE_TYPE_AVAILABLE_INPUT_DEVICES wpe_available_input_devices_get_type()

WPE_API GType wpe_available_input_devices_get_type(void);
#define WPE_TYPE_DISPLAY_ERROR wpe_display_error_get_type()

WPE_API GType wpe_display_error_get_type(void);
/* Enumerations from WPEEGLError.h. */
#define WPE_TYPE_EGL_ERROR wpe_egl_error_get_type()

WPE_API GType wpe_egl_error_get_type(void);
/* Enumerations from WPEEvent.h. */
#define WPE_TYPE_EVENT_TYPE wpe_event_type_get_type()

WPE_API GType wpe_event_type_get_type(void);
#define WPE_TYPE_INPUT_SOURCE wpe_input_source_get_type()

WPE_API GType wpe_input_source_get_type(void);
#define WPE_TYPE_MODIFIERS wpe_modifiers_get_type()

WPE_API GType wpe_modifiers_get_type(void);
/* Enumerations from WPEGamepad.h. */
#define WPE_TYPE_GAMEPAD_BUTTON wpe_gamepad_button_get_type()

WPE_API GType wpe_gamepad_button_get_type(void);
#define WPE_TYPE_GAMEPAD_AXIS wpe_gamepad_axis_get_type()

WPE_API GType wpe_gamepad_axis_get_type(void);
/* Enumerations from WPEGestureController.h. */
#define WPE_TYPE_GESTURE wpe_gesture_get_type()

WPE_API GType wpe_gesture_get_type(void);
/* Enumerations from WPEInputMethodContext.h. */
#define WPE_TYPE_INPUT_PURPOSE wpe_input_purpose_get_type()

WPE_API GType wpe_input_purpose_get_type(void);
#define WPE_TYPE_INPUT_HINTS wpe_input_hints_get_type()

WPE_API GType wpe_input_hints_get_type(void);
/* Enumerations from WPESettings.h. */
#define WPE_TYPE_SETTINGS_ERROR wpe_settings_error_get_type()

WPE_API GType wpe_settings_error_get_type(void);
#define WPE_TYPE_SETTINGS_HINTING_STYLE wpe_settings_hinting_style_get_type()

WPE_API GType wpe_settings_hinting_style_get_type(void);
#define WPE_TYPE_SETTINGS_SUBPIXEL_LAYOUT wpe_settings_subpixel_layout_get_type()

WPE_API GType wpe_settings_subpixel_layout_get_type(void);
#define WPE_TYPE_SETTINGS_SOURCE wpe_settings_source_get_type()

WPE_API GType wpe_settings_source_get_type(void);
/* Enumerations from WPEToplevel.h. */
#define WPE_TYPE_TOPLEVEL_STATE wpe_toplevel_state_get_type()

WPE_API GType wpe_toplevel_state_get_type(void);
/* Enumerations from WPEView.h. */
#define WPE_TYPE_VIEW_ERROR wpe_view_error_get_type()

WPE_API GType wpe_view_error_get_type(void);
G_END_DECLS

#endif /* WPEEnumTypes_h */

/* Generated data ends here */

